==> haskell-data-default-0.7.1.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default
version:              0.7.1.2
visibility:           public
id:                   data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
key:                  data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  931600f1465d0e17d3004bbeee88853f
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default
hs-libraries:         HSdata-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    data-default-instances-containers-0.1.0.3-4o1vrLdrHKiIw8vCgZ7ZVY
    data-default-instances-dlist-0.0.1.2-2IlAwfYsa6CApnNt5TyU0P
    data-default-instances-old-locale-0.0.1.1-CTD6HwOFYKXGE0Nto5XfgO

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-0.7.1.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default
version:              0.7.1.2
visibility:           public
id:                   data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
key:                  data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  80124ad6883d81fd70a42b8100767d1c
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default
hs-libraries:         HSdata-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
depends:
    base-4.17.2.1 data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    data-default-instances-containers-0.1.0.3-9AZa3k8GyIQ5Jra3Lt11HS
    data-default-instances-dlist-0.0.1.2-9KXJdZnk6AxIOw86Hl4VO9
    data-default-instances-old-locale-0.0.1.1-9qJoP0h8lKv246PgEbx1ol

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
